package org.communiquons.dccaggregator.adapters

import android.content.Context
import android.view.LayoutInflater
import android.view.View
import android.view.ViewGroup
import android.widget.ArrayAdapter
import com.google.zxing.BarcodeFormat
import com.journeyapps.barcodescanner.BarcodeEncoder
import org.communiquons.dccaggregator.R
import org.communiquons.dccaggregator.databinding.QrEntryBinding
import org.communiquons.dccaggregator.ext.toDimensSize
import org.communiquons.dccaggregator.data.Certificate

class CertificatesAdapter(cxt: Context, list: ArrayList<Certificate>) :
    ArrayAdapter<Certificate>(cxt, 0, list) {

    private val qrSize by lazy {
        R.dimen.qr_code_widget_size.toDimensSize(context).toInt()
    }

    override fun getView(position: Int, convertView: View?, parent: ViewGroup): View {
        val binding =
            if (convertView == null)
                QrEntryBinding.inflate(LayoutInflater.from(context), parent, false)
            else QrEntryBinding.bind(convertView)

        val cert = getItem(position) as Certificate

        // Generate Qr code
        val bitmap =
            BarcodeEncoder().encodeBitmap(cert.encoded, BarcodeFormat.QR_CODE, qrSize, qrSize)
        binding.certQrCode.setImageBitmap(bitmap)


        binding.userName.text = cert.fullName
        binding.dateOfBirth.text = cert.dateOfBirth
        binding.certificateDescription.text = cert.descText(context)

        return binding.root
    }
}