package org.communiquons.dccaggregator.apis

import android.content.Context
import org.communiquons.dccaggregator.TAC_RES_BASE_URL
import retrofit2.Response
import retrofit2.http.GET

class ConfigurationEntry(
    val name: String,
    val value: Any,
)

class ConfigurationWrapper(val config: List<ConfigurationEntry>)

class ParsedConfig(val activityPassGenerationServerPublicKey: String)

interface TousAntiCovidAPI {
    @GET("Config/config.json")
    suspend fun config(): Response<ConfigurationWrapper>
}

class TousAntiCovidAPIClient {

    private val tacAPI by lazy {
        getRetrofitService(
            TAC_RES_BASE_URL,
            TousAntiCovidAPI::class.java
        )
    }

    suspend fun getConfig(): ParsedConfig {
        val res = tacAPI.config()
        if (!res.isSuccessful)
            throw Exception("Request failed with status ${res.code()}\n${res.errorBody()}")

        return ParsedConfig(
            activityPassGenerationServerPublicKey = res.body()!!.config
                .find { it -> it.name == "app.activityPass.generationServerPublicKey" }!!.value as String
        )
    }
}