package org.communiquons.dccaggregator.helper

import android.content.Context
import androidx.preference.PreferenceManager
import org.communiquons.dccaggregator.GENERATED_CERT_KEY
import org.communiquons.dccaggregator.PREF_CERTS_LIST_KEY
import org.communiquons.dccaggregator.data.Certificate

class CertificatesList(context: Context) {
    private val prefsManager = PreferenceManager.getDefaultSharedPreferences(context)

    /**
     * The list of certificates, as a strings list
     */
    private var listString
        get() = prefsManager.getStringSet(PREF_CERTS_LIST_KEY, HashSet())!!
        set(v) = prefsManager.edit().putStringSet(PREF_CERTS_LIST_KEY, v).apply()


    /**
     * Get the aggregated certificate
     */
    var aggregatedCertificate
        get() = prefsManager.getString(GENERATED_CERT_KEY, null)?.let { it -> Certificate(it) }
        set(v) {
            if (v != null)
                prefsManager.edit().putString(GENERATED_CERT_KEY, v.encoded).apply()
            else
                prefsManager.edit().remove(GENERATED_CERT_KEY).apply()
        }

    /**
     * Check whether a certificate has already been generated or not
     */
    val hasGeneratedCertificate get() = prefsManager.contains(GENERATED_CERT_KEY)

    /**
     * The list of decoded certificates
     */
    val certsList get() = listString.map { t -> Certificate(t) }

    /**
     * Check if a certificate is already present in the list or not
     */
    fun hasCertificate(cert: Certificate): Boolean {
        return certsList.any { it.id == cert.id }
    }

    /**
     * Add a certificate to the list
     */
    fun addCertificate(cert: Certificate) {
        val list = HashSet(listString)
        list.add(cert.encoded)
        listString = list
    }

    /**
     * Remove a certificate from the list
     */
    fun removeCertificate(cert: Certificate) {
        val list = HashSet(listString)
        list.remove(cert.encoded)
        listString = list
    }


}
