package org.communiquons.dccaggregator.viewmodel

import android.util.Log
import androidx.lifecycle.LiveData
import androidx.lifecycle.MutableLiveData
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import kotlinx.coroutines.Dispatchers
import kotlinx.coroutines.Job
import kotlinx.coroutines.launch
import kotlinx.coroutines.withContext
import org.communiquons.dccaggregator.apis.AggregateResult
import org.communiquons.dccaggregator.apis.DccLightAPIClient
import org.communiquons.dccaggregator.apis.TousAntiCovidAPIClient
import org.communiquons.dccaggregator.helper.CertificatesList

class CertsManagerViewModel() : ViewModel() {
    private val TAG = CertsManagerViewModel::class.java.canonicalName

    lateinit var certsManager: CertificatesList

    private val _reqStatus = MutableLiveData<String?>("")
    val reqStatus: LiveData<String?> = _reqStatus

    fun requestCertificate(): Job {
        return viewModelScope.launch(Dispatchers.IO) {
            try {
                withContext(Dispatchers.IO) {
                    // First, fetch current signing key
                    val config = TousAntiCovidAPIClient().getConfig()
                    Log.d("Server Primary Key", config.activityPassGenerationServerPublicKey)

                    // Then aggregate certificates
                    val res = DccLightAPIClient().aggregateCertificates(
                        config.activityPassGenerationServerPublicKey,
                        certsManager.certsList
                    )

                    withContext(Dispatchers.Main) {
                        if (res is AggregateResult.Success) {
                            certsManager.aggregatedCertificate = res.cert
                        } else if (res is AggregateResult.Error) {
                            throw Exception(res.error)
                        }

                        _reqStatus.value = null
                    }
                }
            } catch (e: Exception) {
                e.printStackTrace()

                withContext(Dispatchers.Main) {
                    _reqStatus.value = e.message ?: "Request failed!"
                }
            }
        }
    }

}